#!/bin/bash

rm -rf data exp mfcc

# Data preparation
local/prepare_data.sh wavsjanee
local/prepare_dict.sh
utils/prepare_lang.sh --position-dependent-phones false data/local/dict "<SIL>" data/local/lang data/lang
local/prepare_lm.sh
# There are no out of vocabulary words in the training set, so data/lang/oov.txt
# is expected to contain SIL as the SPN (spoken noise) dummy - it has no effect
# The file context_indep.txt contains all the phones which are not "real phones": 
# i.e. silence (SIL), spoken noise (SPN), non-spoken noise (NSN), and laughter (LAU).

## Feature extraction
for x in train test; do 
	steps/make_mfcc.sh data/$x exp/make_mfcc/$x mfcc
	#steps/make_plp.sh data/$x exp/make_mfcc/$x mfcc
	steps/compute_cmvn_stats.sh data/$x exp/make_mfcc/$x mfcc
done

## Check correct formatting of data/train and fix possible (minor) formatting errors
# Correction: this already happens in steps/make_mfcc.sh, above...
#utils/validate_data_dir.sh data/train
#utils/fix_data_dir.sh data/train

## Mono training
# Num of gaussians established experimentally: nor too little data warnings
# with this number when approaching from 1000.
#steps/train_mono.sh --nj 1 --cmd utils/run.pl --totgauss 600 data/train data/lang exp/mono
steps/train_mono.sh --nj 1 --cmd utils/run.pl data/train data/lang exp/mono

## Graph compilation
utils/mkgraph.sh --mono data/lang_test_tg exp/mono exp/mono/graph

## Decoding
steps/decode.sh --nj 1 --cmd utils/run.pl exp/mono/graph data/test exp/mono/decode_test

# Get alignments from monophone system.
steps/align_si.sh --nj 1 --cmd utils/run.pl data/train data/lang_test_tg exp/mono exp/mono_ali

# Train tri1 [first triphone pass]
# The 9000 value produces warnings in the log files and is not appropriate for this training set
#steps/train_deltas.sh --cmd "$train_cmd" 1800 9000 data/train data/lang_test_tg exp/mono_ali exp/tri1
#steps/train_deltas.sh --cmd utils/run.pl 100 600 data/train data/lang_test_tg exp/mono_ali exp/tri1
steps/train_deltas.sh --cmd utils/run.pl 10 100 data/train data/lang_test_tg exp/mono_ali exp/tri1
#steps/train_deltas.sh --cmd utils/run.pl 200 1000 data/train data/lang_test_tg exp/mono_ali exp/tri1

# Triphone 1 graph compilation
utils/mkgraph.sh data/lang_test_tg exp/tri1 exp/tri1/graph

## Decoding
steps/decode.sh --nj 1 --cmd utils/run.pl exp/tri1/graph data/test exp/tri1/decode_test
#for x in exp/*/decode*; do [ -d $x ] && grep WER $x/wer_* | utils/best_wer.sh; done

# align tri1
steps/align_si.sh --nj 1 --cmd utils/run.pl --use-graphs true data/train data/lang_test_tg exp/tri1 exp/tri1_ali
#sudo steps/align_si.sh --nj 1 --cmd utils/run.pl --use-graphs true data/train data/lang_test_tg exp/tri1 exp/tri1_ali

# train tri2a [delta+delta-deltas]
#steps/train_deltas.sh --cmd "$train_cmd" 1800 9000 data/train data/lang_test_tg exp/tri1_ali exp/tri2a
steps/train_deltas.sh --cmd utils/run.pl 10 100 data/train data/lang_test_tg exp/tri1_ali exp/tri2a
#steps/train_deltas.sh --cmd utils/run.pl 200 1000 data/train data/lang_test_tg exp/tri1_ali exp/tri2a

# tri2a graph compilation
utils/mkgraph.sh data/lang_test_tg exp/tri2a exp/tri2a/graph

## Decoding
#steps/decode.sh --nj 1 --cmd "$decode_cmd" exp/tri2a/graph data/test exp/tri2a/decode_test
steps/decode.sh --nj 1 --cmd utils/run.pl exp/tri2a/graph data/test exp/tri2a/decode_test

# train tri2b [LDA+MLLT]
#train_lda_mllt.sh does not finish executing and get stuck on line 94/95:
#est-lda --write-full-matrix=$dir/full.mat --dim=$dim $dir/0.mat $dir/lda.*.acc 2>$dir/log/lda_est.log || exit 1;
#steps/train_lda_mllt.sh --cmd "$train_cmd" --splice-opts "--left-context=3 --right-context=3" 1800 9000 data/train data/lang_test_tg exp/tri1_ali exp/tri2b
steps/train_lda_mllt.sh --cmd utils/run.pl --dim 7 --splice-opts "--left-context=3 --right-context=3" 10 100 data/train data/lang_test_tg exp/tri1_ali exp/tri2b
#steps/train_lda_mllt.sh --cmd utils/run.pl --dim 40 --splice-opts "--left-context=3 --right-context=3" 200 1000 data/train data/lang_test_tg exp/tri1_ali exp/tri2b

#est-lda --write-full-matrix=exp/tri2b/full.mat --dim=40 exp/tri2b/0.mat exp/tri2b/lda.*.acc 2>exp/tri2b/log/lda_est.log || exit 1;

# tri2b graph compilation
utils/mkgraph.sh data/lang_test_tg exp/tri2b exp/tri2b/graph

## Decoding & final scoring
steps/decode.sh --nj 1 --cmd utils/run.pl exp/tri2b/graph data/test exp/tri2b/decode_test
for x in exp/*/decode*; do [ -d $x ] && grep WER $x/wer_* | utils/best_wer.sh; done
